
/* Generated data (by glib-mkenums) */


/* enumerations from "gnome-client.h" */
    (void) gnome_interact_style_get_type ();

    (void) gnome_dialog_type_get_type ();

    (void) gnome_save_style_get_type ();

    (void) gnome_restart_style_get_type ();

    (void) gnome_client_state_get_type ();

    (void) gnome_client_flags_get_type ();


/* enumerations from "gnome-dateedit.h" */
    (void) gnome_date_edit_flags_get_type ();


/* enumerations from "gnome-druid-page-edge.h" */
    (void) gnome_edge_position_get_type ();


/* enumerations from "gnome-icon-list.h" */
    (void) gnome_icon_list_mode_get_type ();


/* enumerations from "gnome-types.h" */
    (void) gnome_preferences_type_get_type ();


/* enumerations from "gnome-winhints.h" */
    (void) gnome_win_layer_get_type ();

    (void) gnome_win_state_get_type ();

    (void) gnome_win_hints_get_type ();

    (void) gnome_win_app_state_get_type ();


/* Generated data ends here */

